Coverage report

# Coverage report: 72%

Hot-keys on this page

n s m x b p c change column sorting

Module | statements | missing | excluded | branches | partial | coverage
--- | --- | --- | --- | --- | --- | ---
Total | 2579 | 628 | 5 | 790 | 88 | 72%
jutil/__init__.py | 1 | 0 | 0 | 0 | 0 | 100%
jutil/admin.py | 147 | 32 | 3 | 48 | 6 | 75%
jutil/apps.py | 3 | 0 | 0 | 0 | 0 | 100%
jutil/auth.py | 15 | 0 | 0 | 4 | 0 | 100%
jutil/bank_const_be.py | 2 | 0 | 0 | 0 | 0 | 100%
jutil/bank_const_dk.py | 1 | 0 | 0 | 0 | 0 | 100%
jutil/bank_const_fi.py | 2 | 0 | 0 | 0 | 0 | 100%
jutil/bank_const_iban.py | 1 | 0 | 0 | 0 | 0 | 100%
jutil/bank_const_se.py | 1 | 0 | 0 | 0 | 0 | 100%
jutil/cache.py | 34 | 34 | 0 | 20 | 0 | 0%
jutil/command.py | 94 | 22 | 0 | 52 | 7 | 72%
jutil/dates.py | 115 | 21 | 0 | 34 | 10 | 78%
jutil/dict.py | 43 | 6 | 0 | 20 | 5 | 79%
jutil/email.py | 111 | 81 | 0 | 44 | 5 | 25%
jutil/format.py | 212 | 30 | 0 | 96 | 11 | 84%
jutil/logs.py | 16 | 8 | 0 | 6 | 0 | 36%
jutil/management/__init__.py | 0 | 0 | 0 | 0 | 0 | 100%
jutil/management/commands/__init__.py | 0 | 0 | 0 | 0 | 0 | 100%
jutil/management/commands/make_bank_const_dk.py | 51 | 51 | 0 | 18 | 0 | 0%
jutil/management/commands/make_bank_const_fi.py | 60 | 60 | 0 | 24 | 0 | 0%
jutil/management/commands/make_bank_const_se.py | 84 | 84 | 0 | 40 | 0 | 0%
jutil/management/commands/setpass.py | 19 | 19 | 0 | 4 | 0 | 0%
jutil/management/commands/test_email.py | 36 | 26 | 0 | 10 | 0 | 22%
jutil/middleware.py | 74 | 3 | 0 | 20 | 6 | 90%
jutil/model.py | 62 | 5 | 0 | 28 | 8 | 86%
jutil/modelfields.py | 8 | 0 | 0 | 0 | 0 | 100%
jutil/object.py | 20 | 20 | 0 | 6 | 0 | 0%
jutil/parse.py | 33 | 9 | 0 | 12 | 5 | 64%
jutil/permissions.py | 12 | 12 | 0 | 2 | 0 | 0%
jutil/request.py | 39 | 16 | 0 | 10 | 2 | 51%
jutil/responses.py | 39 | 11 | 0 | 6 | 3 | 69%
jutil/sms.py | 15 | 15 | 0 | 8 | 0 | 0%
jutil/testing.py | 57 | 28 | 0 | 14 | 1 | 42%
jutil/tests.py | 697 | 17 | 0 | 68 | 3 | 97%
jutil/urls.py | 20 | 1 | 0 | 4 | 1 | 92%
jutil/validators.py | 345 | 8 | 0 | 132 | 9 | 96%
jutil/xml.py | 100 | 7 | 0 | 60 | 6 | 92%
manage.py | 10 | 2 | 2 | 0 | 0 | 80%

No items found using the specified filter.